@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from benedict.dicts.base import BaseDict
 from benedict.dicts.keylist import keylist_util
 from benedict.utils import type_util
@@ -7,12 +5,12 @@ from benedict.utils import type_util
 
 class KeylistDict(BaseDict):
     def __init__(self, *args, **kwargs):
-        super(KeylistDict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def __contains__(self, key):
         if type_util.is_list_or_tuple(key):
             return self._contains_by_keys(key)
-        return super(KeylistDict, self).__contains__(key)
+        return super().__contains__(key)
 
     def _contains_by_keys(self, keys):
         parent, _, _ = keylist_util.get_item(self, keys)
@@ -24,7 +22,7 @@ class KeylistDict(BaseDict):
         if type_util.is_list_or_tuple(key):
             self._delitem_by_keys(key)
             return
-        super(KeylistDict, self).__delitem__(key)
+        super().__delitem__(key)
 
     def _delitem_by_keys(self, keys):
         parent, key, _ = keylist_util.get_item(self, keys)
@@ -39,7 +37,7 @@ class KeylistDict(BaseDict):
     def __getitem__(self, key):
         if type_util.is_list_or_tuple(key):
             return self._getitem_by_keys(key)
-        return super(KeylistDict, self).__getitem__(key)
+        return super().__getitem__(key)
 
     def _getitem_by_keys(self, keys):
         parent, key, _ = keylist_util.get_item(self, keys)
@@ -51,7 +49,7 @@ class KeylistDict(BaseDict):
         if type_util.is_list_or_tuple(key):
             self._setitem_by_keys(key, value)
             return
-        super(KeylistDict, self).__setitem__(key, value)
+        super().__setitem__(key, value)
 
     def _setitem_by_keys(self, keys, value):
         keylist_util.set_item(self, keys, value)
@@ -59,7 +57,7 @@ class KeylistDict(BaseDict):
     def get(self, key, default=None):
         if type_util.is_list_or_tuple(key):
             return self._get_by_keys(key, default)
-        return super(KeylistDict, self).get(key, default)
+        return super().get(key, default)
 
     def _get_by_keys(self, keys, default=None):
         parent, key, _ = keylist_util.get_item(self, keys)
@@ -72,7 +70,7 @@ class KeylistDict(BaseDict):
     def pop(self, key, *args):
         if type_util.is_list_or_tuple(key):
             return self._pop_by_keys(key, *args)
-        return super(KeylistDict, self).pop(key, *args)
+        return super().pop(key, *args)
 
     def _pop_by_keys(self, keys, *args):
         parent, key, _ = keylist_util.get_item(self, keys)
