@@ -1,3 +1,4 @@
+import pathlib
 import re
 from datetime import datetime
 from decimal import Decimal
@@ -70,6 +71,10 @@ def is_not_none(val):
     return val is not None
 
 
+def is_path(val):
+    return isinstance(val, pathlib.Path)
+
+
 def is_regex(val):
     return isinstance(val, regex)
 
